@@ -63,6 +63,12 @@ class BaseStorageTests(object):
     def test_empty_get_multi(self, s):
         assert list(s.get_multi([])) == []
 
+    def test_get_multi_duplicates(self, s, get_item):
+        href, etag = s.upload(get_item())
+        (href2, item, etag2), = s.get_multi([href] * 2)
+        assert href2 == href
+        assert etag2 == etag
+
     def test_upload_already_existing(self, s, get_item):
         item = get_item()
         s.upload(item)
@@ -117,6 +123,8 @@ class BaseStorageTests(object):
         href, etag = s.upload(get_item())
         assert s.has(href)
         assert not s.has('asd')
+        s.delete(href, etag)
+        assert not s.has(href)
 
     def test_update_others_stay_the_same(self, s, get_item):
         info = dict([
@@ -139,39 +147,22 @@ class BaseStorageTests(object):
 class SupportsCollections(object):
 
     def test_discover(self, get_storage_args, get_item):
-        collections = set()
+        expected = set()
 
-        def main():
-            for i in range(1, 5):
-                collection = 'test{}'.format(i)
-                # Create collections on-the-fly for most storages
-                # Except ownCloud, which already has all of them, and more
-                i += 1
-                s = self.storage_class(
-                    **get_storage_args(collection=collection))
-
-                # radicale ignores empty collections during discovery
-                item = get_item()
-                s.upload(item)
-
-                collections.add(s.collection)
-        main()  # remove leftover variables from loop for safety
+        for i in range(1, 5):
+            # Create collections, but use the "collection" attribute because
+            # Radicale requires file extensions in their names.
+            expected.add(
+                self.storage_class(
+                    **get_storage_args(collection='test{}'.format(i))
+                ).collection
+            )
 
         d = self.storage_class.discover(
             **get_storage_args(collection=None))
 
-        def main():
-            for s in d:
-                if s.collection not in collections:
-                    # ownCloud has many more collections, as on-the-fly
-                    # creation doesn't really work there. Skip those
-                    # collections, as they are not relevant to us.
-                    print('Skipping {}'.format(s.collection))
-                    continue
-                collections.remove(s.collection)
-        main()
-
-        assert not collections
+        actual = set(s.collection for s in d)
+        assert actual >= expected
 
     def test_discover_collection_arg(self, get_storage_args):
         args = get_storage_args(collection='test2')
